body{
    margin:0;
    padding: 0;
    background-color: #e5e8e6;
    font-family: 'Open Sans', sans-serif;
    color: #506784;
    -webkit-user-select: none;  /* Chrome all / Safari all */
    -moz-user-select: none;     /* Firefox all */
    -ms-user-select: none;      /* IE 10+ */
    user-select: none;          /* Likely future */
}

.modal {
    display: block;  /*Hidden by default */
    position: fixed; /* Stay in place */
    z-index: 1000; /* Sit on top */
    left: 0;
    top: 0;
    width: 100%; /* Full width */
    height: 100%; /* Full height */
    overflow: auto; /* Enable scroll if needed */
    background-color: rgb(0,0,0); /* Fallback color */
    background-color: rgba(0,0,0,0.4); /* Black w/ opacity */
}
.modal-content {
    background-color: white;
    margin: 5% auto; /* 15% from the top and centered */
    padding: 20px;
    width: 50%; /* Could be more or less, depending on screen size */
    color:#506784;
}
._dash-undo-redo {
  display: none;
}

.app-title{
    color:white;
    font-size:3rem;
    letter-spacing:-.1rem;
    vertical-align:middle
}

.header{
    margin:0px;
    background-color:#2a3f5f;
    height:70px;
    color:white;
    padding-right:2%;
    padding-left:2%
}

.indicator{
    border:1px solid #C8D4E3;
    border-radius: 3px;
    background-color: white;
    height:100px;
    vertical-align:middle;
}

.indicator_text{
    text-align: center;
    float: left;
    font-size: 15px;
    }

.indicator_value{
    text-align:center;
    color: #2a3f5f;
    font-size: 35px;
}

.add{
    height: 34px;
    background: #119DFF;
    border: 1px solid #119DFF;
    color: white;
}


.chart_div{
    background-color: white;
    border: 1px solid #C8D4E3;
    border-radius: 3px;
    height: 300px;
}


.chart_div p{
    color: #2a3f5f;
    font-size: 13px;
    text-align: center;   
}




td{
    text-align: left;
    padding: 0px;
}
table{
    border: 1px;
    font-size:1.3rem;
    width:100%;
    font-family:Ubuntu;
}

.tabs_div{
    margin:0px;
    height:30px;
    font-size:13px;
    margin-top:1px
}