.header-box {
  position: fixed;
  z-index: 100;
}
.header-box .el-menu{
  border-radius: 0px;
}
.title {
  font-size: 20px;
  font-weight: bold;
  color: #fff;
  float: left;
  height: 60px;
  line-height: 60px;
  margin: 0 20px;
  position: relative;
  box-sizing: border-box;
}
.user {
  font-size: 16px;
  color: #fff;
  float: right;
  height: 60px;
  line-height: 60px;
  margin: 0 20px;
  position: relative;
  box-sizing: border-box;
}
.content {
  margin-top: 60px;
  padding: 10px;
}
